<?php
/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://sharabindu.com
 * @since      1.5.2
 *
 * @package    Qrc_composer
 * @subpackage Qrc_composer/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Qrc_composer
 * @subpackage Qrc_composer/admin
 * @author     Sharabindu Bakshi <sharabindu86@gmail.com>
 */
class Qrc_composer_Admin
{



    /**
     * The ID of this plugin.
     *
     * @since    1.5.2
     * @access   private
     * @var      string    $plugin_name    The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.5.2
     * @access   private
     * @var      string    $version    The current version of this plugin.
     */
    private $version;

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.5.2
     * @param      string    $plugin_name       The name of this plugin.
     * @param      string    $version    The version of this plugin.
     */
    public function __construct($plugin_name, $version)
    {

        $this->plugin_name = $plugin_name;
        $this->version = $version;

        require_once plugin_dir_path(dirname(__FILE__)) . 'admin/class_qr_code_print.php';
        require_once plugin_dir_path(dirname(__FILE__)) . 'admin/class_qr_code_list_view.php';
        require_once plugin_dir_path(dirname(__FILE__)) . 'admin/class-qrc_composer_settings.php';
        require_once plugin_dir_path(dirname(__FILE__)) . 'admin/class_qrc_code_vcard.php';

        require_once plugin_dir_path(dirname(__FILE__)) . 'admin/class-qrc-admin-main.php';
        require_once plugin_dir_path(dirname(__FILE__)) . 'admin/extra/qrrcode_shortcode_func.php';
        require_once plugin_dir_path(dirname(__FILE__)) . 'admin/class_qrc_shortcode.php';
        require_once plugin_dir_path(dirname(__FILE__)) . 'admin/class-qrc-plugin-redirect.php';
        
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/metadata/class-yoo-filed-data.php';
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/metadata/class_qrc_defaultmeta.php';

        $plugin_name = new QR_code_Print_light();
        $plugin_name = new QR_code_List_View_Light();
        $plugin_name = new QR_code_Admin_settings();

    }


    /**
     * Register the stylesheets for the admin area.
     *
     * @since    1.5.2
     */
    public function enqueue_styles()
    {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Qrc_composer_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Qrc_composer_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */
        wp_enqueue_style('wp-color-picker');
        wp_enqueue_style($this->plugin_name, QRC_COMPOSER_URL . 'admin/css/qrc_composer-admin.css', array() , $this->version, 'all');

    }

    /**
     * Register the JavaScript for the admin area.
     *
     * @since    1.5.2
     */
    public function enqueue_scripts()
    {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Qrc_composer_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Qrc_composer_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */
        wp_enqueue_script('wp-color-picker');
        wp_enqueue_script($this->plugin_name, QRC_COMPOSER_URL . 'public/js/qrious.min.js', array(
            'jquery'
        ) , $this->version, false);  


        wp_enqueue_script("bbq", QRC_COMPOSER_URL . 'admin/js/jquery.bbq.min.js', array(
            'jquery'
        ) , $this->version, false);

    }

    /**
     * Setting link.
     *
     * @since    1.5.2
     */

    public function plugin_settings_link($links)
    {

        return array_merge(array(
            '<a href="' . admin_url('admin.php?page=qr_composer') . '">' . __('Settings', 'qrc_composer') . '</a>',
            '<a class="qrccompoer_pro_link" href="https://sharabindu.com/plugins/qr-code-composer/">' . __('Go Pro', 'qrc_composer') . '</a>',
        ) , $links);

    }


   


    public function adminFooterTextQR(){

          if (isset($_GET['page']) && strpos($_GET['page'], QRC_COMPOSER_PLUGIN_ID) !== false) {

      ?>

         <div id="footer_contaciner" role="contentinfo">
                 <p id="qr_plg_id"><?php echo esc_html__('Thank you for using','qr-code-composer') ?> <strong><?php echo esc_html__('QR Code Composer','qr-code-composer') ?></strong> <span class="dashicons dashicons-smiley"></span> &nbsp;&nbsp;
                  <?php echo esc_html__('Please rate on','qr-code-composer') ?> <a class="qrc_composer_dash_strat" href="https://wordpress.org/support/plugin/qr-code-composer/reviews/" target="_blank" rel="noopener noreferrer"><i class="dashicons dashicons-star-filled"></i><i class="dashicons dashicons-star-filled"></i><i class="dashicons dashicons-star-filled"></i><i class="dashicons dashicons-star-filled"></i><i class="dashicons dashicons-star-filled"></i></a> <a href="https://wordpress.org/support/plugin/qr-code-composer/reviews/" target="_blank" rel="noopener noreferrer"><?php echo esc_html__('WordPress.org','qr-code-composer') ?></a> <?php echo esc_html__('to help us spread the word!  ','qr-code-composer') ?></p>
    
             <div class="clear"></div>
         </div>
     <?php
     }
     }  
}

