<?php
/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://sharabindu.com
 * @since      1.5.2
 *
 * @package    Qrc_composer
 * @subpackage Qrc_composer/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Qrc_composer
 * @subpackage Qrc_composer/public
 * @author     Sharabindu Bakshi <sharabindu86@gmail.com>
 */
class Qrc_composer_Public
{

    /**
     * The ID of this plugin.
     *
     * @since    1.5.2
     * @access   private
     * @var      string    $plugin_name    The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.5.2
     * @access   private
     * @var      string    $version    The current version of this plugin.
     */
    private $version;

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.5.2
     * @param      string    $plugin_name       The name of the plugin.
     * @param      string    $version    The version of this plugin.
     */
    public function __construct($plugin_name, $version)
    {

        $this->plugin_name = plugin_basename(__FILE__);
        $this->version = $version;

    }

    /**
     * Register the stylesheets for the public-facing side of the site.
     *
     * @since    1.5.2
     */
    public function enqueue_styles()
    {


    }

    /**
     * Register the JavaScript for the public-facing side of the site.
     *
     * @since    1.5.2
     */
    public function enqueue_scripts()
    {


        wp_enqueue_script("qrious", QRC_COMPOSER_URL . 'public/js/qrious.min.js', array(
            'jquery'
        ) , $this->version, false);

    }

    /**
     * This function is display Qr code on frontend.
     */

    public function qcr_code_element($content)
    {

        $current_id = get_the_ID();
        $current_title = get_the_title($current_id);
        $current_id_link = get_the_permalink($current_id);
        //$qrc_meta_display = get_post_meta($current_id, 'qrc_metabox', true);

        $qrc_meta_display = get_post_meta($current_id, 'qrc_metabox', true) ? get_post_meta($current_id, 'qrc_metabox', true) : 1;

        $qrc_qr_image = '';
        $post_types = get_post_types();
        $options = get_option('qrc_composer_settings');

        if (!empty($options))
        {
            $singlular_exclude = is_singular($options);
        }
        else
        {
            $singlular_exclude = '';
        }

        $qrc_alignment = isset($options['qrc_select_alignment']) ? $options['qrc_select_alignment'] : 'left';
        $qrc_size = isset($options['qr_code_picture_size_width']) ? $options['qr_code_picture_size_width'] : 200;
        $download_qr = isset($options['qr_download_text']) ? $options['qr_download_text'] : 'Download QR';
        $qr_download_hide = isset($options['qr_download_hide']) ? $options['qr_download_hide'] : 'no';
        $qr_dwnbtn_color = isset($options['qr_dwnbtn_color']) ? $options['qr_dwnbtn_color'] : '#000';
        $qr_dwnbtnbg_color = isset($options['qr_dwnbtnbg_color']) ? $options['qr_dwnbtnbg_color'] : '#c8fd8c';


        if($qr_download_hide == 'no'){
            $qr_download_ = '<a id="download_QRC_con">
                <button type="button" style="min-width:' . $qrc_size . 'px;color:'.$qr_dwnbtn_color.';background:'.$qr_dwnbtnbg_color.';line-height: 1;border: none;padding: 10px;margin-top: 5px;" class="uqr_code_btn">' . $download_qr . '</button>
                </a>';
        }else{
            $qr_download_ = '';
        }
        if (($qrc_meta_display == '2') or ($singlular_exclude) or (is_front_page()) or (is_home()) or is_singular('product'))
        {     
            $content .= '';
        }
        else
        {


      $content .= sprintf('<div style="text-align:' . $qrc_alignment . '"><img id="QRC_Com_COntent" alt="%s" ></div>'.$qr_download_.'
            <script>function QRC_WOOCON(){var qr = window.qr = new QRious({
              element: document.getElementById("QRC_Com_COntent"),
              size: %s,
              value: "%s"
            });
            jQuery("#download_QRC_con").click(function() {
        download(jQuery("#QRC_Com_COntent").attr("src"),"%s.png","image/png");
        });}QRC_WOOCON();</script>',$current_title,$qrc_size, $current_id_link,$current_title);
        }
        return $content;

    }

    /**
     * This function is Provide for Createing Woocomerce custom product tab for Qr Code
     */

    public function woo_custom_product_tabs($tabs)
    {

        $options = get_option('qrc_composer_settings');

        $qrc_wc_ptab_name = isset($options['qrc_wc_ptab_name']) ? $options['qrc_wc_ptab_name'] : 'QR Code';

        $tabs['qty_pricing_tab'] = array(
            'title' => $qrc_wc_ptab_name ,
            'priority' => 100,
            'callback' => array(
                $this,
                'woo_qrc_tab_content'
            )
        );

        $qrc_meta_display = get_post_meta(get_the_ID() , 'qrc_metabox', true);
      
        if (!empty($options))
        {
            $singlular_wc_exclude = is_singular($options);
        }
        else
        {
            $singlular_wc_exclude = '';
        }

        if (($qrc_meta_display == '2') or ($singlular_wc_exclude))
        {
            return false;
        }
        else
        {
            return $tabs;

        }

    }

    /**
     *  Woocomerce custom product tab Call Back function
     */

    public function woo_qrc_tab_content()
    {

        $current_title = get_the_title(get_the_id());
        $current_id_link = get_the_permalink(get_the_id());

        $options = get_option('qrc_composer_settings');

        $qrc_wc_alignment = isset($options['qrc_wc_select_alignment']) ? $options['qrc_wc_select_alignment'] : 'left';
        $qrc_wc_size = isset($options['qr_code_picture_size_width']) ? $options['qr_code_picture_size_width'] : 200;
        $download_qr = isset($options['qr_download_text']) ? $options['qr_download_text'] : 'Download QR';
        $qr_download_hide = isset($options['qr_download_hide']) ? $options['qr_download_hide'] : 'no';
        $qr_dwnbtn_color = isset($options['qr_dwnbtn_color']) ? $options['qr_dwnbtn_color'] : '#000';
        $qr_dwnbtnbg_color = isset($options['qr_dwnbtnbg_color']) ? $options['qr_dwnbtnbg_color'] : '#c8fd8c';

        if($qr_download_hide == 'no'){
            $qr_download_ = '<a id="DownWooQRC">
                <button type="button" style="min-width:' . $qrc_wc_size . 'px;color:'.$qr_dwnbtn_color.';background:'.$qr_dwnbtnbg_color.';line-height: 1;border: none;padding: 10px;margin-top: 5px;" class="uqr_code_btn">' . $download_qr . '</button>
                </a>';
        }else{
            $qr_download_ = '';
        }
        return printf('<div style="text-align:' . $qrc_wc_alignment . '"><img id="WooQR_Composer" alt="%s" ></div>'.$qr_download_.'<script>function QRC_PR_CON(){var qr = window.qr = new QRious({element: document.getElementById("WooQR_Composer"),size: %s,value: "%s"});jQuery("#DownWooQRC").click(function() {
                download(jQuery("#WooQR_Composer").attr("src"),"%s.png","image/png");
                })}QRC_PR_CON();</script>',$current_title,$qrc_wc_size, $current_id_link,$current_title);
    }

}

